@@ -174,7 +174,7 @@ bookmarks_add (Bookmarks   *bookmarks,
 	if (avoid_duplicates) {
 		GList *scan;
 		for (scan = bookmarks->list; scan; scan = scan->next)
-			if (strcmp ((char*) scan->data, path) == 0)
+			if (same_uri ((char*) scan->data, path))
 				return;
 	}
 	
@@ -202,7 +202,7 @@ get_link_from_path (GList      *list,
 	GList *scan;
 
 	for (scan = list; scan; scan = scan->next)
-		if (strcmp ((char*) scan->data, path) == 0)
+		if (same_uri ((char*) scan->data, path))
 			return scan;
 	
 	return NULL;
@@ -272,7 +272,6 @@ bookmarks_remove_from (Bookmarks *bookmarks,
 		char *path = link->data;
 
 		bookmarks->list = g_list_remove_link (bookmarks->list, link);
-		g_list_free (link);
 
 		if (get_link_from_path (bookmarks->list, path) == NULL) {
 			my_remove (bookmarks->names, path);
@@ -280,6 +279,7 @@ bookmarks_remove_from (Bookmarks *bookmarks,
 		}
 
 		g_free (link->data);
+		g_list_free (link);
 	}
 }
 
