@@ -24,6 +24,7 @@
 #include <stdio.h>
 #include <glib.h>
 #include <glib/gprintf.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
 #include "glib-utils.h"
 
 
@@ -300,36 +301,26 @@ _g_utf8_strsplit (const char     *str,
 char *
 _g_utf8_strstrip (const char *str)
 {
-	const char *s;
-	const char *t;
-
 	if (str == NULL)
 		return NULL;
+	return g_strstrip (g_strdup (str));
+}
 
-	s = str;
 
-	do {
-		gunichar ch = g_utf8_get_char (s);
-		if (! g_unichar_isspace (ch))
-			break;
-		s = g_utf8_next_char (s);
-	} while (*s != 0);
+gboolean
+_g_utf8_all_spaces (const char *utf8_string)
+{
+	gunichar c;
+	
+	c = g_utf8_get_char (utf8_string);
+	while (c != 0) {
+		if (! g_unichar_isspace (c))
+			return FALSE;
+		utf8_string = g_utf8_next_char (utf8_string);
+		c = g_utf8_get_char (utf8_string);
+	}
 
-	if (*s == 0)
-		return NULL;
-
-	/**/
-
-	t = s;
-
-	do {
-		gunichar ch = g_utf8_get_char (t);
-		if (g_unichar_isspace (ch))
-			break;
-		t = g_utf8_next_char (t);
-	} while (*t != 0);
-
-	return g_strndup (s, t - s);
+	return TRUE;
 }
 
 
@@ -355,3 +346,162 @@ debug (const char *file,
 #else /* ! DEBUG */
 #endif
 }
+
+
+GList *
+get_file_list_from_url_list (char *url_list)
+{
+	GList *list = NULL;
+	int    i;
+	char  *url_start, *url_end;
+
+	url_start = url_list;
+	while (url_start[0] != '\0') {
+		char *escaped;
+		char *unescaped;
+
+		if (strncmp (url_start, "file:", 5) == 0) {
+			url_start += 5;
+			if ((url_start[0] == '/') 
+			    && (url_start[1] == '/')) url_start += 2;
+		}
+
+		i = 0;
+		while ((url_start[i] != '\0')
+		       && (url_start[i] != '\r')
+		       && (url_start[i] != '\n')) i++;
+		url_end = url_start + i;
+
+		escaped = g_strndup (url_start, url_end - url_start);
+		unescaped = gnome_vfs_unescape_string_for_display (escaped);
+		g_free (escaped);
+
+		list = g_list_prepend (list, unescaped);
+
+		url_start = url_end;
+		i = 0;
+		while ((url_start[i] != '\0')
+		       && ((url_start[i] == '\r')
+			   || (url_start[i] == '\n'))) i++;
+		url_start += i;
+	}
+	
+	return g_list_reverse (list);
+}
+
+
+int
+strcmp_null_tollerant (const char *s1, const char *s2)
+{
+	if ((s1 == NULL) && (s2 == NULL))
+		return 0;
+	else if ((s1 != NULL) && (s2 == NULL))
+		return 1;
+	else if ((s1 == NULL) && (s2 != NULL))
+		return -1;
+	else 
+		return strcmp (s1, s2);
+}
+
+
+GList *
+_g_list_insert_list_before (GList *list1,
+			    GList *sibling,
+			    GList *list2)
+{
+  if (!list2)
+    {
+      return list1;
+    }
+  else if (!list1) 
+    {
+      return list2;
+    }
+  else if (sibling) 
+    {
+      GList *list2_last = g_list_last (list2);
+      if (sibling->prev)
+	{
+	  sibling->prev->next = list2;
+	  list2->prev = sibling->prev;
+	  sibling->prev = list2_last;
+	  list2_last->next = sibling;
+	  return list1;
+	}
+      else
+	{
+	  sibling->prev = list2_last;
+	  list2_last->next = sibling;
+	  return list2;
+	}
+    }
+  else
+    {
+      return g_list_concat (list1, list2);
+    }
+}
+
+
+gboolean
+str_ends_with (const char *s1, 
+	       const char *s2)
+{
+	int s1_len, s2_len;
+
+	if ((s1 == NULL) || (s2 == NULL))
+		return FALSE;
+
+	s1_len = strlen (s1);
+	s2_len = strlen (s2);
+
+	if (s2_len > s1_len)
+		return FALSE;
+
+	return strncmp (s1 + (s1_len - s2_len), s2, s2_len) == 0;
+}
+
+
+/**/
+
+
+IdleCall*
+idle_call_new (DoneFunc func,
+	       gpointer data)
+{
+	IdleCall *call = g_new0(IdleCall, 1);
+	call->func = func;
+	call->data = data;
+	return call;
+}
+
+
+void
+idle_call_free (IdleCall *call)
+{
+	g_free (call);
+}
+
+
+static gboolean
+idle_call_exec_cb (gpointer data)
+{
+	IdleCall *call = data;
+	(*call->func) (call->data);
+	return FALSE;
+}
+
+
+guint
+idle_call_exec (IdleCall *call,
+		gboolean  use_idle_cb)
+{
+	if (use_idle_cb)
+		return g_idle_add_full (G_PRIORITY_DEFAULT_IDLE,
+					idle_call_exec_cb, 
+					call, 
+					(GDestroyNotify) idle_call_free);
+	else {
+		(*call->func) (call->data);
+		return 0;
+	}
+}
