@@ -74,6 +74,13 @@ gfv_get_widget (GthFileView   *file_view)
 }
 
 
+static GtkWidget *
+gfv_get_drag_source (GthFileView   *file_view)
+{
+	return NULL;
+}
+
+
 /* To avoid excesive recomputes during insertion/deletion */
 
 
@@ -446,6 +453,36 @@ gfv_set_no_image_text (GthFileView *file_view,
 }
 
 
+static void
+gfv_set_drag_dest_pos (GthFileView *file_view,
+		       int          x,
+		       int          y)
+{
+}
+
+
+static void
+gfv_get_drag_dest_pos (GthFileView     *file_view,
+		       int             *pos)
+{
+	*pos = -1;
+}
+
+
+static void
+gfv_set_reorderable (GthFileView  *file_view,
+		     gboolean      value)
+{
+}
+
+
+static gboolean
+gfv_get_reorderable (GthFileView  *file_view)
+{
+	return FALSE;
+}
+
+
 /* Interactive search */
 
 
@@ -481,6 +518,7 @@ gth_file_view_class_init (GthFileViewClass *file_view_class)
 	file_view_class->set_vadjustment      = gfv_set_vadjustment;
 	file_view_class->get_vadjustment      = gfv_get_vadjustment;
 	file_view_class->get_widget           = gfv_get_widget;
+	file_view_class->get_drag_source      = gfv_get_drag_source;
 	file_view_class->freeze               = gfv_freeze;
 	file_view_class->thaw                 = gfv_thaw;
 	file_view_class->is_frozen            = gfv_is_frozen;
@@ -528,6 +566,10 @@ gth_file_view_class_init (GthFileViewClass *file_view_class)
 	file_view_class->get_cursor           = gfv_get_cursor;
 	file_view_class->update_icon_theme    = gfv_update_icon_theme;
 	file_view_class->set_no_image_text    = gfv_set_no_image_text;
+	file_view_class->set_drag_dest_pos    = gfv_set_drag_dest_pos;
+	file_view_class->get_drag_dest_pos    = gfv_get_drag_dest_pos;
+	file_view_class->set_reorderable      = gfv_set_reorderable;
+	file_view_class->get_reorderable      = gfv_get_reorderable;
 	file_view_class->set_enable_search    = gfv_set_enable_search;
 	file_view_class->get_enable_search    = gfv_get_enable_search;
 
@@ -571,7 +613,7 @@ gth_file_view_init (GthFileView *file_view)
 GType
 gth_file_view_get_type (void)
 {
-	static guint type = 0;
+	static GType type = 0;
 
 	if (! type) {
 		GTypeInfo type_info = {
@@ -636,6 +678,13 @@ gth_file_view_get_widget (GthFileView *file_view)
 }
 
 
+GtkWidget *
+gth_file_view_get_drag_source (GthFileView *file_view)
+{
+	return 	GTH_FILE_VIEW_GET_CLASS (file_view)->get_drag_source (file_view);
+}
+
+
 /* To avoid excesive recomputes during insertion/deletion */
 
 
@@ -1033,6 +1082,41 @@ gth_file_view_set_no_image_text (GthFileView *file_view,
 }
 
 
+/* DnD */
+
+
+void
+gth_file_view_set_drag_dest_pos (GthFileView *file_view,
+				 int          x,
+				 int          y)
+{
+	GTH_FILE_VIEW_GET_CLASS (file_view)->set_drag_dest_pos (file_view, x, y);
+}
+
+
+void
+gth_file_view_get_drag_dest_pos (GthFileView     *file_view,
+				 int             *pos)
+{
+	GTH_FILE_VIEW_GET_CLASS (file_view)->get_drag_dest_pos (file_view, pos);
+}
+
+
+void
+gth_file_view_set_reorderable (GthFileView  *file_view,
+			       gboolean      value)
+{
+	GTH_FILE_VIEW_GET_CLASS (file_view)->set_reorderable (file_view, value);
+}
+
+
+gboolean
+gth_file_view_get_reorderable (GthFileView  *file_view)
+{
+	return GTH_FILE_VIEW_GET_CLASS (file_view)->get_reorderable (file_view);
+}
+
+
 /* Interactive search */
 
 
