@@ -31,7 +31,7 @@
 
 #include "async-pixbuf-ops.h"
 #include "gth-pixbuf-op.h"
-#include "gthumb-window.h"
+#include "gth-window.h"
 #include "gthumb-stock.h"
 #include "pixbuf-utils.h"
 
@@ -42,13 +42,12 @@
 
 
 typedef struct {
-	GThumbWindow *window;
+	GthWindow    *window;
 	ImageViewer  *viewer;
 	GdkPixbuf    *image;
 	GdkPixbuf    *orig_pixbuf;
 	GdkPixbuf    *new_pixbuf;
 
-	gboolean      original_modified;
 	gboolean      modified;
 
 	GladeXML     *gui;
@@ -88,7 +87,8 @@ static void
 apply_changes (DialogData *data, 
 	       GdkPixbuf  *src, 
 	       GdkPixbuf  *dest, 
-	       gboolean    preview)
+	       gboolean    dialog_preview,
+	       gboolean    window_preview)
 {
 	double       brightness;
 	double       contrast;
@@ -102,14 +102,14 @@ apply_changes (DialogData *data,
 						 brightness / 127.0,
 						 contrast / 127.0);
 
-	if (preview) {
+	if (dialog_preview) {
 		g_signal_connect (G_OBJECT (pixop),
 				  "pixbuf_op_done",
 				  G_CALLBACK (preview_done_cb),
 				  data);
 		gth_pixbuf_op_start (pixop);
 	} else {
-		window_exec_pixbuf_op (data->window, pixop);
+		gth_window_exec_pixbuf_op (data->window, pixop, window_preview);
 		g_object_unref (pixop);
 	}		
 }
@@ -120,9 +120,7 @@ static void
 ok_cb (GtkWidget  *widget, 
        DialogData *data)
 {
-	apply_changes (data, data->image, data->image, FALSE);
-	image_viewer_set_pixbuf (data->viewer, data->image);
-	window_image_set_modified (data->window, TRUE);
+	apply_changes (data, data->image, data->image, FALSE, FALSE);
 	gtk_widget_destroy (data->dialog);
 }
 
@@ -132,10 +130,8 @@ static void
 cancel_cb (GtkWidget  *widget, 
 	   DialogData *data)
 {
-	if (data->modified) {
+	if (data->modified) 
 		image_viewer_set_pixbuf (data->viewer, data->image);
-		window_image_set_modified (data->window, data->original_modified);
-	}
 	gtk_widget_destroy (data->dialog);
 }
 
@@ -148,7 +144,7 @@ preview_cb (GtkWidget  *widget,
 	GdkPixbuf *preview;
 
 	preview = gdk_pixbuf_copy (data->image);
-	apply_changes (data, preview, preview, FALSE);
+	apply_changes (data, preview, preview, FALSE, TRUE);
 	g_object_unref (preview);
 
 	data->modified = TRUE;
@@ -169,7 +165,7 @@ static void
 range_value_changed (GtkRange   *range,
 		     DialogData *data)
 {
-	apply_changes (data, data->orig_pixbuf, data->new_pixbuf, TRUE);
+	apply_changes (data, data->orig_pixbuf, data->new_pixbuf, TRUE, FALSE);
 }
 
 
@@ -208,7 +204,7 @@ gimp_scale_entry_new (GtkWidget  *parent_box,
 
 
 void
-dlg_brightness_contrast (GThumbWindow *window)
+dlg_brightness_contrast (GthWindow *window)
 {
 	DialogData *data;
 	GtkWidget  *ok_button;
@@ -223,7 +219,6 @@ dlg_brightness_contrast (GThumbWindow *window)
 
 	data = g_new0 (DialogData, 1);
 	data->window = window;
-	data->original_modified = window_image_get_modified (window);
 	data->gui = glade_xml_new (GTHUMB_GLADEDIR "/" GLADE_FILE, NULL,
 				   NULL);
 
@@ -257,7 +252,7 @@ dlg_brightness_contrast (GThumbWindow *window)
 							 1.0,
 							 10.0);
 
-	data->viewer = IMAGE_VIEWER (window->viewer);
+	data->viewer = gth_window_get_image_viewer (window);
 
 	reset_image = glade_xml_get_widget (data->gui, "bc_reset_image");
 	gtk_image_set_from_stock (GTK_IMAGE (reset_image), GTHUMB_STOCK_RESET, GTK_ICON_SIZE_MENU);
@@ -327,8 +322,8 @@ dlg_brightness_contrast (GThumbWindow *window)
 	/* Run dialog. */
 
 	gtk_window_set_transient_for (GTK_WINDOW (data->dialog),
-				      GTK_WINDOW (window->app));
+				      GTK_WINDOW (window));
 	gtk_widget_show (data->dialog);
 
-	apply_changes (data, data->orig_pixbuf, data->new_pixbuf, TRUE);
+	apply_changes (data, data->orig_pixbuf, data->new_pixbuf, TRUE, FALSE);
 }
